==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/VoidEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescription } from "./VoidEventArgsDescription";
/**
 * @hidden
 */
var VoidEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(VoidEventArgsDescriptionMetadata, _super);
    function VoidEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VoidEventArgsDescriptionMetadata.b = function (a) {
        if (VoidEventArgsDescriptionMetadata.a == null) {
            VoidEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VoidEventArgsDescriptionMetadata.c(VoidEventArgsDescriptionMetadata.a);
        }
        if (a.k(VoidEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(VoidEventArgsDescriptionMetadata.a);
    };
    VoidEventArgsDescriptionMetadata.c = function (a) {
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    VoidEventArgsDescriptionMetadata.d = function (a) {
        VoidEventArgsDescriptionMetadata.b(a);
        a.ad("VoidEventArgs", function () { return new VoidEventArgsDescription(); });
        a.ac("VoidEventArgs", VoidEventArgsDescriptionMetadata.a);
    };
    VoidEventArgsDescriptionMetadata.$t = markType(VoidEventArgsDescriptionMetadata, 'VoidEventArgsDescriptionMetadata');
    VoidEventArgsDescriptionMetadata.a = null;
    return VoidEventArgsDescriptionMetadata;
}(Base));
export { VoidEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/VoidEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescription } from "./VoidEventArgsDescription";
/**
 * @hidden
 */
var VoidEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(VoidEventArgsDescriptionMetadata, _super);
    function VoidEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VoidEventArgsDescriptionMetadata.b = function (a) {
        if (VoidEventArgsDescriptionMetadata.a == null) {
            VoidEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VoidEventArgsDescriptionMetadata.c(VoidEventArgsDescriptionMetadata.a);
        }
        if (a.k(VoidEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(VoidEventArgsDescriptionMetadata.a);
    };
    VoidEventArgsDescriptionMetadata.c = function (a) {
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    VoidEventArgsDescriptionMetadata.d = function (a) {
        VoidEventArgsDescriptionMetadata.b(a);
        a.ae("VoidEventArgs", function () { return new VoidEventArgsDescription(); });
        a.ad("VoidEventArgs", VoidEventArgsDescriptionMetadata.a);
    };
    VoidEventArgsDescriptionMetadata.$t = markType(VoidEventArgsDescriptionMetadata, 'VoidEventArgsDescriptionMetadata');
    VoidEventArgsDescriptionMetadata.a = null;
    return VoidEventArgsDescriptionMetadata;
}(Base));
export { VoidEventArgsDescriptionMetadata };
